run method
Runs this command.
The return value is wrapped in a Future if necessary and returned by
CommandRunner.runCommand.
Implementation
@override
void run() {
_UpdateHelper.update();
}
Runs this command.
The return value is wrapped in a Future if necessary and returned by
CommandRunner.runCommand.
@override
void run() {
_UpdateHelper.update();
}